[Python-checkins] r42922 - sandbox/trunk/datetime/PSF.py

tim.peters python-checkins at python.org
Wed Mar 8 21:53:15 CET 2006


Author: tim.peters
Date: Wed Mar  8 21:53:14 2006
New Revision: 42922

Modified:
   sandbox/trunk/datetime/PSF.py
Log:
PSF board mtgs are now on Mondays.


Modified: sandbox/trunk/datetime/PSF.py
==============================================================================
--- sandbox/trunk/datetime/PSF.py	(original)
+++ sandbox/trunk/datetime/PSF.py	Wed Mar  8 21:53:14 2006
@@ -7,7 +7,7 @@
 """
 
 from datetime import datetime
-from dateutil import TUESDAY, weekday_of_month
+from dateutil import MONDAY, weekday_of_month
 
 from US import Eastern, Central, Mountain, Pacific
 from EU import UTC, London, Amsterdam
@@ -23,9 +23,9 @@
 
 # A vector of 12 datetimes, all in Eastern.
 def psf_times_for_a_year(year):
     # 1pm Eastern on the second Tuesday of the month.
     base = datetime(year, 1, 1, 13, tzinfo=Eastern)
-    return [weekday_of_month(TUESDAY, base.replace(month=i), 1)
+    return [weekday_of_month(MONDAY, base.replace(month=i), 1)
             for i in range(1, 13)]
 
 # Eastern is always displayed first.
@@ -23,9 +23,9 @@
 # A vector of 12 datetimes, all in Eastern.
 def psf_times_for_a_year(year):
-    # 1pm Eastern on the second Tuesday of the month.
+    # 1pm Eastern on the second Monday of the month.
     base = datetime(year, 1, 1, 13, tzinfo=Eastern)


More information about the Python-checkins mailing list